Learn R Programming

PDQutils (version 0.1.1)

cumulant2moment: Convert raw cumulants to moments.

Description

Conversion of a vector of raw cumulatnts to moments.

Usage

cumulant2moment(kappa)

Arguments

kappa
a vector of the raw cumulants. The first element is the first cumulant, which is also the first moment.

Value

  • a vector of the raw moments.

Details

The 'raw' cumulants $\kappa_i$ are connected to the 'raw' (uncentered) moments, $\mu_i'$ via the equation $$\mu_n' = \kappa_n + \sum_{m=1}^{n-1} {n-1 \choose m-1} \kappa_m \mu_{n-m}'$$

See Also

moment2cumulant

Examples

Run this code
# normal distribution, mean 0, variance 1
n.mom <- cumulant2moment(c(0,1,0,0,0,0))
# normal distribution, mean 1, variance 1
n.mom <- cumulant2moment(c(1,1,0,0,0,0))

Run the code above in your browser using DataLab